# Installation
## Stable release

To install SCRUB, run this command in your terminal:

    pip install nasa-scrub
    
To install SCRUB only for the current user, user the `--user` flag during installation:

    pip install --user nasa-scrub

To upgrade your existing version to the latest version of SCRUB, run this command in your terminal:

    pip install --upgrade nasa-scrub

This is the preferred method to install scrub, as it will always install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

## From sources

The sources for scrub can be downloaded from the [Github repo](https://github.com/nasa/scrub).

You can either clone the public repository:

    git clone https://github.com/nasa/scrub.git

Or download the [tarball](https://github.com/nasa/scrub/archive/master.tar.gz):

    curl -OJL https://github.com/nasa/scrub/archive/tarball/master

Once you have a copy of the source, you can install it with:

    python3 setup.py install

